<?php    
/**
 *extreme-lite Theme Customizer
 *
 * @package Extreme Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function extreme_lite_customize_register( $wp_customize ) {	
	
	function extreme_lite_sanitize_dropdown_pages( $page_id, $setting ) {
	  // Ensure $input is an absolute integer.
	  $page_id = absint( $page_id );	
	  // If $page_id is an ID of a published page, return it; otherwise, return the default.
	  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
	}

	function extreme_lite_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	} 
	
	function extreme_lite_sanitize_phone_number( $phone ) {
		// sanitize phone
		return preg_replace( '/[^\d+]/', '', $phone );
	} 
	
	
	function extreme_lite_sanitize_excerptrange( $number, $setting ) {	
		// Ensure input is an absolute integer.
		$number = absint( $number );	
		// Get the input attributes associated with the setting.
		$atts = $setting->manager->get_control( $setting->id )->input_attrs;	
		// Get minimum number in the range.
		$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );	
		// Get maximum number in the range.
		$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );	
		// Get step.
		$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );	
		// If the number is within the valid range, return it; otherwise, return the default
		return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
	}

	function extreme_lite_sanitize_number_absint( $number, $setting ) {
		// Ensure $number is an absolute integer (whole number, zero or greater).
		$number = absint( $number );		
		// If the input is an absolute integer, return it; otherwise, return the default
		return ( $number ? $number : $setting->default );
	}
	
	// Ensure is an absolute integer
	function extreme_lite_sanitize_choices( $input, $setting ) {
		global $wp_customize; 
		$control = $wp_customize->get_control( $setting->id ); 
		if ( array_key_exists( $input, $control->choices ) ) {
			return $input;
		} else {
			return $setting->default;
		}
	}
	
		
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	
	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.logo h1 a',
		'render_callback' => 'extreme_lite_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.logo p',
		'render_callback' => 'extreme_lite_customize_partial_blogdescription',
	) );
		
	 	
	//Panel for section & control
	$wp_customize->add_panel( 'extreme_lite_panel_settings', array(
		'priority' => 4,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Extreme Lite Settings', 'extreme-lite' ),		
	) );

	$wp_customize->add_section('extreme_lite_themelayout',array(
		'title' => __('Site Layout Settings','extreme-lite'),			
		'priority' => 1,
		'panel' => 	'extreme_lite_panel_settings',          
	));		
	
	$wp_customize->add_setting('extreme_lite_boxlayoutoption',array(
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'extreme_lite_boxlayoutoption', array(
    	'section'   => 'extreme_lite_themelayout',    	 
		'label' => __('Check to Show Box Layout','extreme-lite'),
		'description' => __('check for box layout','extreme-lite'),
    	'type'      => 'checkbox'
     )); //Layout Settings 
	
	$wp_customize->add_setting('extreme_lite_colorscheme',array(
		'default' => '#ec9327',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'extreme_lite_colorscheme',array(
			'label' => __('Color Scheme','extreme-lite'),			
			'section' => 'colors',
			'settings' => 'extreme_lite_colorscheme'
		))
	);
	
	$wp_customize->add_setting('extreme_lite_hovercolor_option',array(
		'default' => '#23c16c',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'extreme_lite_hovercolor_option',array(
			'label' => __('Second Color Options','extreme-lite'),			
			'section' => 'colors',
			'settings' => 'extreme_lite_hovercolor_option'
		))
	);
	
	$wp_customize->add_setting('extreme_lite_mainnavcolor',array(
		'default' => '#282828',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'extreme_lite_mainnavcolor',array(
			'label' => __('Navigation font Color','extreme-lite'),			
			'section' => 'colors',
			'settings' => 'extreme_lite_mainnavcolor'
		))
	);
	
	
	$wp_customize->add_setting('extreme_lite_mainnavcoloractive',array(
		'default' => '#ec9327',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'extreme_lite_mainnavcoloractive',array(
			'label' => __('Navigation Hover/Active Color','extreme-lite'),			
			'section' => 'colors',
			'settings' => 'extreme_lite_mainnavcoloractive'
		))
	);
	
	
	 //Header Contact info
	$wp_customize->add_section('extreme_lite_hdrinfo_section',array(
		'title' => __('Header Contact Info','extreme-lite'),				
		'priority' => null,
		'panel' => 	'extreme_lite_panel_settings',
	));	
	
	$wp_customize->add_setting('extreme_lite_phonenumber',array(
		'default' => null,
		'sanitize_callback' => 'extreme_lite_sanitize_phone_number'	
	));
	
	$wp_customize->add_control('extreme_lite_phonenumber',array(	
		'type' => 'text',
		'label' => __('Enter phone number here','extreme-lite'),
		'section' => 'extreme_lite_hdrinfo_section',
		'setting' => 'extreme_lite_phonenumber'
	));
	
	$wp_customize->add_setting('extreme_lite_emailinfo',array(
		'sanitize_callback' => 'sanitize_email'
	));
	
	$wp_customize->add_control('extreme_lite_emailinfo',array(
		'type' => 'email',
		'label' => __('Enter email id here','extreme-lite'),
		'section' => 'extreme_lite_hdrinfo_section'
	));	
	
	
	$wp_customize->add_setting('extreme_lite_facebooklink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'	
	));
	
	$wp_customize->add_control('extreme_lite_facebooklink',array(
		'label' => __('Add facebook link here','extreme-lite'),
		'section' => 'extreme_lite_hdrinfo_section',
		'setting' => 'extreme_lite_facebooklink'
	));	
	
	$wp_customize->add_setting('extreme_lite_twitterlink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('extreme_lite_twitterlink',array(
		'label' => __('Add twitter link here','extreme-lite'),
		'section' => 'extreme_lite_hdrinfo_section',
		'setting' => 'extreme_lite_twitterlink'
	));

	
	$wp_customize->add_setting('extreme_lite_linkedinlink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('extreme_lite_linkedinlink',array(
		'label' => __('Add linkedin link here','extreme-lite'),
		'section' => 'extreme_lite_hdrinfo_section',
		'setting' => 'extreme_lite_linkedinlink'
	));
	
	$wp_customize->add_setting('extreme_lite_instagramlink',array(
		'default' => null,
		'sanitize_callback' => 'esc_url_raw'
	));
	
	$wp_customize->add_control('extreme_lite_instagramlink',array(
		'label' => __('Add instagram link here','extreme-lite'),
		'section' => 'extreme_lite_hdrinfo_section',
		'setting' => 'extreme_lite_instagramlink'
	));		
	
	$wp_customize->add_setting('extreme_lite_hdrinfo_section_show',array(
		'default' => false,
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'extreme_lite_hdrinfo_section_show', array(
	   'settings' => 'extreme_lite_hdrinfo_section_show',
	   'section'   => 'extreme_lite_hdrinfo_section',
	   'label'     => __('Check To show Header contact info','extreme-lite'),
	   'type'      => 'checkbox'
	 ));//Show Contact Info
	 
	 	 	
	//Frontpage Slide Section		
	$wp_customize->add_section( 'extreme_lite_homeslider_sections', array(
		'title' => __('Homepage Slider Sections', 'extreme-lite'),
		'priority' => null,
		'description' => __('Default image size for slider is 1400 x 755 pixel.','extreme-lite'), 
		'panel' => 	'extreme_lite_panel_settings',           			
    ));
	
	$wp_customize->add_setting('extreme_lite_slidepage1',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'extreme_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('extreme_lite_slidepage1',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slide 1:','extreme-lite'),
		'section' => 'extreme_lite_homeslider_sections'
	));	
	
	$wp_customize->add_setting('extreme_lite_slidepage2',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'extreme_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('extreme_lite_slidepage2',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slide 2:','extreme-lite'),
		'section' => 'extreme_lite_homeslider_sections'
	));	
	
	$wp_customize->add_setting('extreme_lite_slidepage3',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'extreme_lite_sanitize_dropdown_pages'
	));
	
	$wp_customize->add_control('extreme_lite_slidepage3',array(
		'type' => 'dropdown-pages',
		'label' => __('Select page for slide 3:','extreme-lite'),
		'section' => 'extreme_lite_homeslider_sections'
	));	//frontpage Slider Section	
	
	//Slider Excerpt Length
	$wp_customize->add_setting( 'extreme_lite_slidepage_excerptlength', array(
		'default'              => 10,
		'type'                 => 'theme_mod',		
		'sanitize_callback'    => 'extreme_lite_sanitize_excerptrange',		
	) );
	$wp_customize->add_control( 'extreme_lite_slidepage_excerptlength', array(
		'label'       => __( 'Slider Excerpt length','extreme-lite' ),
		'section'     => 'extreme_lite_homeslider_sections',
		'type'        => 'range',
		'settings'    => 'extreme_lite_slidepage_excerptlength','input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );	
	
	$wp_customize->add_setting('extreme_lite_slide_discbtn',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('extreme_lite_slide_discbtn',array(	
		'type' => 'text',
		'label' => __('Enter button name here','extreme-lite'),
		'section' => 'extreme_lite_homeslider_sections',
		'setting' => 'extreme_lite_slide_discbtn'
	)); // slider discover more button text
	
		
	$wp_customize->add_setting('extreme_lite_homeslider_sections_show',array(
		'default' => false,
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'extreme_lite_homeslider_sections_show', array(
	    'settings' => 'extreme_lite_homeslider_sections_show',
	    'section'   => 'extreme_lite_homeslider_sections',
	    'label'     => __('Check To Show This Section','extreme-lite'),
	   'type'      => 'checkbox'
	 ));//Show front Page Slider Sections	
	 
	 
	 //Four Column Sections
	$wp_customize->add_section('extreme_lite_fourcolumn_sections', array(
		'title' => __('Four Column Sections','extreme-lite'),
		'description' => __('Select pages from the dropdown for four column sections','extreme-lite'),
		'priority' => null,
		'panel' => 	'extreme_lite_panel_settings',          
	));
		
	$wp_customize->add_setting('extreme_lite_fourcolpage1',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'extreme_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'extreme_lite_fourcolpage1',array(
		'type' => 'dropdown-pages',			
		'section' => 'extreme_lite_fourcolumn_sections',
	));		
	
	$wp_customize->add_setting('extreme_lite_fourcolpage2',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'extreme_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'extreme_lite_fourcolpage2',array(
		'type' => 'dropdown-pages',			
		'section' => 'extreme_lite_fourcolumn_sections',
	));
	
	$wp_customize->add_setting('extreme_lite_fourcolpage3',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'extreme_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'extreme_lite_fourcolpage3',array(
		'type' => 'dropdown-pages',			
		'section' => 'extreme_lite_fourcolumn_sections',
	));
	
	$wp_customize->add_setting('extreme_lite_fourcolpage4',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'extreme_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'extreme_lite_fourcolpage4',array(
		'type' => 'dropdown-pages',			
		'section' => 'extreme_lite_fourcolumn_sections',
	));

	
	$wp_customize->add_setting( 'extreme_lite_fourcolpage_excerpt_length', array(
		'default'              => 8,
		'type'                 => 'theme_mod',		
		'sanitize_callback'    => 'extreme_lite_sanitize_excerptrange',		
	) );
	$wp_customize->add_control( 'extreme_lite_fourcolpage_excerpt_length', array(
		'label'       => __( 'four column excerpt length','extreme-lite' ),
		'section'     => 'extreme_lite_fourcolumn_sections',
		'type'        => 'range',
		'settings'    => 'extreme_lite_fourcolpage_excerpt_length','input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );
	
	$wp_customize->add_setting('extreme_lite_fourcolpage_readmoretext',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('extreme_lite_fourcolpage_readmoretext',array(	
		'type' => 'text',
		'label' => __('Enter read more button text','extreme-lite'),
		'section' => 'extreme_lite_fourcolumn_sections',
		'setting' => 'extreme_lite_fourcolpage_readmoretext'
	)); // Four column read more button text		
	
	
	$wp_customize->add_setting('extreme_lite_fourcolumn_sections_show',array(
		'default' => false,
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));		
	
	$wp_customize->add_control( 'extreme_lite_fourcolumn_sections_show', array(
	   'settings' => 'extreme_lite_fourcolumn_sections_show',
	   'section'   => 'extreme_lite_fourcolumn_sections',
	   'label'     => __('Check To Show This Section','extreme-lite'),
	   'type'      => 'checkbox'
	 ));//Show Four column sections
	 
	 
	 //Welcome Sections
	$wp_customize->add_section('extreme_lite_welcomepage_sections', array(
		'title' => __('Welcome Sections','extreme-lite'),
		'description' => __('Select pages from the dropdown for welcome sections','extreme-lite'),
		'priority' => null,
		'panel' => 	'extreme_lite_panel_settings',          
	));
	
	$wp_customize->add_setting('extreme_lite_welcomepage_sections_subtitle',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('extreme_lite_welcomepage_sections_subtitle',array(	
		'type' => 'text',
		'label' => __('Enter sub title here','extreme-lite'),
		'section' => 'extreme_lite_welcomepage_sections',
		'setting' => 'extreme_lite_welcomepage_sections_subtitle'
	)); // Welcome sub title	
		
	$wp_customize->add_setting('extreme_lite_welcomesinglepage',array(
		'default' => '0',			
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'extreme_lite_sanitize_dropdown_pages'
	));
 
	$wp_customize->add_control(	'extreme_lite_welcomesinglepage',array(
		'type' => 'dropdown-pages',			
		'section' => 'extreme_lite_welcomepage_sections',
	));	
	
	$wp_customize->add_setting( 'extreme_lite_excerpt_length_welcomesinglepage', array(
		'default'              => 100,
		'type'                 => 'theme_mod',		
		'sanitize_callback'    => 'extreme_lite_sanitize_excerptrange',		
	) );
	$wp_customize->add_control( 'extreme_lite_excerpt_length_welcomesinglepage', array(
		'label'       => __( 'Circle box excerpt length','extreme-lite' ),
		'section'     => 'extreme_lite_welcomepage_sections',
		'type'        => 'range',
		'settings'    => 'extreme_lite_excerpt_length_welcomesinglepage','input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );
	
	$wp_customize->add_setting('extreme_lite_welcomesinglepage_readmoretext',array(
		'default' => null,
		'sanitize_callback' => 'sanitize_text_field'	
	));
	
	$wp_customize->add_control('extreme_lite_welcomesinglepage_readmoretext',array(	
		'type' => 'text',
		'label' => __('Enter read more button text','extreme-lite'),
		'section' => 'extreme_lite_welcomepage_sections',
		'setting' => 'extreme_lite_welcomesinglepage_readmoretext'
	)); // welcome read more button text	
	
	
	$wp_customize->add_setting('extreme_lite_welcomepage_sections_show',array(
		'default' => false,
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));		
	
	$wp_customize->add_control( 'extreme_lite_welcomepage_sections_show', array(
	   'settings' => 'extreme_lite_welcomepage_sections_show',
	   'section'   => 'extreme_lite_welcomepage_sections',
	   'label'     => __('Check To Show This Section','extreme-lite'),
	   'type'      => 'checkbox'
	 ));//Show Welcome sections
	
	 
	 //Blog Posts Settings
	$wp_customize->add_panel( 'extreme_lite_blogpost_settings', array(
		'priority' => 3,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Blog Posts Settings', 'extreme-lite' ),		
	) );
	
	$wp_customize->add_section('extreme_lite_blogmeta_options',array(
		'title' => __('Blog Meta Options','extreme-lite'),			
		'priority' => null,
		'panel' => 	'extreme_lite_blogpost_settings', 	         
	));		
	
	$wp_customize->add_setting('extreme_lite_hide_blogdate',array(
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'extreme_lite_hide_blogdate', array(
    	'label' => __('Check to hide post date','extreme-lite'),	
		'section'   => 'extreme_lite_blogmeta_options', 
		'setting' => 'extreme_lite_hide_blogdate',		
    	'type'      => 'checkbox'
     )); //Blog Post Date
	 
	 
	 $wp_customize->add_setting('extreme_lite_hide_postcats',array(
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'extreme_lite_hide_postcats', array(
		'label' => __('Check to hide post category','extreme-lite'),	
    	'section'   => 'extreme_lite_blogmeta_options',		
		'setting' => 'extreme_lite_hide_postcats',		
    	'type'      => 'checkbox'
     )); //blog Posts category	 
	 
	 
	 $wp_customize->add_section('extreme_lite_postfeatured_image',array(
		'title' => __('Posts Featured image','extreme-lite'),			
		'priority' => null,
		'panel' => 	'extreme_lite_blogpost_settings', 	         
	));		
	
	$wp_customize->add_setting('extreme_lite_hide_postfeatured_image',array(
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'extreme_lite_hide_postfeatured_image', array(
		'label' => __('Check to hide post featured image','extreme-lite'),
    	'section'   => 'extreme_lite_postfeatured_image',		
		'setting' => 'extreme_lite_hide_postfeatured_image',	
    	'type'      => 'checkbox'
     )); //Posts featured image
	
	$wp_customize->add_section('extreme_lite_blogpost_content_settings',array(
		'title' => __('Blog Posts Excerpt Settings','extreme-lite'),			
		'priority' => null,
		'panel' => 	'extreme_lite_blogpost_settings', 	         
	 ));	 
	 
	$wp_customize->add_setting( 'extreme_lite_postsexcerptrange', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'extreme_lite_sanitize_excerptrange',		
	) );
	
	$wp_customize->add_control( 'extreme_lite_postsexcerptrange', array(
		'label'       => __( 'Excerpt length','extreme-lite' ),
		'section'     => 'extreme_lite_blogpost_content_settings',
		'type'        => 'range',
		'settings'    => 'extreme_lite_postsexcerptrange','input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );

    $wp_customize->add_setting('extreme_lite_postsfullcontent',array(
        'default' => 'Excerpt',     
        'sanitize_callback' => 'extreme_lite_sanitize_choices'
	));
	
	$wp_customize->add_control('extreme_lite_postsfullcontent',array(
        'type' => 'select',
        'label' => __('Posts Content','extreme-lite'),
        'section' => 'extreme_lite_blogpost_content_settings',
        'choices' => array(
        	'Content' => __('Content','extreme-lite'),
            'Excerpt' => __('Excerpt','extreme-lite'),
            'No Content' => __('No Excerpt','extreme-lite')
        ),
	) ); 
	
	
	$wp_customize->add_section('extreme_lite_postsinglemeta',array(
		'title' => __('Posts Single Settings','extreme-lite'),			
		'priority' => null,
		'panel' => 	'extreme_lite_blogpost_settings', 	         
	));	
	
	$wp_customize->add_setting('extreme_lite_hide_postdate_fromsingle',array(
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'extreme_lite_hide_postdate_fromsingle', array(
    	'label' => __('Check to hide post date from single','extreme-lite'),	
		'section'   => 'extreme_lite_postsinglemeta', 
		'setting' => 'extreme_lite_hide_postdate_fromsingle',		
    	'type'      => 'checkbox'
     )); //Hide Posts date from single
	 
	 
	 $wp_customize->add_setting('extreme_lite_hide_postcats_fromsingle',array(
		'sanitize_callback' => 'extreme_lite_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'extreme_lite_hide_postcats_fromsingle', array(
		'label' => __('Check to hide post category from single','extreme-lite'),	
    	'section'   => 'extreme_lite_postsinglemeta',		
		'setting' => 'extreme_lite_hide_postcats_fromsingle',		
    	'type'      => 'checkbox'
     )); //Hide blogposts category single
		 
}
add_action( 'customize_register', 'extreme_lite_customize_register' );

function extreme_lite_custom_css(){ 
?>
	<style type="text/css"> 					
        a,
        #sidebar ul li a:hover,
		#sidebar ol li a:hover,	
        .grid-style-2column h3 a:hover,
		.site-footer ul li a:hover, 
		.site-footer ul li.current_page_item a,				
        .postmeta a:hover,
		.welcome-right-48 h4,
		.topsocial-bx a:hover,
        .button:hover,
		h2.services_title span,			
		.blog-postmeta a:hover,
		.blog-postmeta a:focus,
		blockquote::before	
            { color:<?php echo esc_html( get_theme_mod('extreme_lite_colorscheme','#ec9327')); ?>;}					 
            
        .pagination ul li .current, .pagination ul li a:hover, 
        #commentform input#submit:hover,
        .nivo-controlNav a.active,
		.sd-search input, .sd-top-bar-nav .sd-search input,			
		a.blogreadmore,
		a.ReadMoreBtn,
		.column-four-box .equal-height-bx:hover,
		.copyrigh-wrapper:before,										
        #sidebar .search-form input.search-submit,				
        .wpcf7 input[type='submit'],				
        nav.pagination .page-numbers.current,		
		.morebutton,
		.nivo-directionNav a:hover
            { background-color:<?php echo esc_html( get_theme_mod('extreme_lite_colorscheme','#ec9327')); ?>;}
			

		
		.tagcloud a:hover,
		.site-footer h2:after, .site-footer h3:after, .site-footer h4:after, .site-footer h5:after, .site-footer h6:after,
		blockquote
            { border-color:<?php echo esc_html( get_theme_mod('extreme_lite_colorscheme','#ec9327')); ?>;}
			
		#main-site-wrapper a:focus,
		input[type="date"]:focus,
		input[type="search"]:focus,
		input[type="number"]:focus,
		input[type="tel"]:focus,
		input[type="button"]:focus,
		input[type="month"]:focus,
		button:focus,
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="range"]:focus,		
		input[type="password"]:focus,
		input[type="datetime"]:focus,
		input[type="week"]:focus,
		input[type="submit"]:focus,
		input[type="datetime-local"]:focus,		
		input[type="url"]:focus,
		input[type="time"]:focus,
		input[type="reset"]:focus,
		input[type="color"]:focus,
		textarea:focus
            { outline:1px solid <?php echo esc_html( get_theme_mod('extreme_lite_colorscheme','#ec9327')); ?>;}	
			
		
		.nivo-caption .slidermorebtn:hover,
		a.ReadMoreBtn:hover			
            { background-color:<?php echo esc_html( get_theme_mod('extreme_lite_hovercolor_option','#23c16c')); ?>;}
			
			
			
		
		.site-menu-block a,
		.site-menu-block ul li.current_page_parent ul.sub-menu li a,
		.site-menu-block ul li.current_page_parent ul.sub-menu li.current_page_item ul.sub-menu li a,
		.site-menu-block ul li.current-menu-ancestor ul.sub-menu li.current-menu-item ul.sub-menu li a  			
            { color:<?php echo esc_html( get_theme_mod('extreme_lite_mainnavcolor','#282828')); ?>;}	
			
		
		.site-menu-block ul.nav-menu .current_page_item > a,
		.site-menu-block ul.nav-menu .current-menu-item > a,
		.site-menu-block ul.nav-menu .current_page_ancestor > a,
		.site-menu-block ul.nav-menu .current-menu-ancestor > a, 
		.site-menu-block .nav-menu a:hover,
		.site-menu-block .nav-menu a:focus,
		.site-menu-block .nav-menu ul a:hover,
		.site-menu-block .nav-menu ul a:focus,
		.site-menu-block ul li a:hover, 
		.site-menu-block ul li.current-menu-item a,			
		.site-menu-block ul li.current_page_parent ul.sub-menu li.current-menu-item a,
		.site-menu-block ul li.current_page_parent ul.sub-menu li a:hover,
		.site-menu-block ul li.current-menu-item ul.sub-menu li a:hover,
		.site-menu-block ul li.current-menu-ancestor ul.sub-menu li.current-menu-item ul.sub-menu li a:hover 		 			
            { color:<?php echo esc_html( get_theme_mod('extreme_lite_mainnavcoloractive','#ec9327')); ?>;}
			
		.hdrtopcart .cart-count
            { background-color:<?php echo esc_html( get_theme_mod('extreme_lite_mainnavcoloractive','#ec9327')); ?>;}		
			
		#main-site-wrapper .site-menu-block a:focus		 			
            { outline:1px solid <?php echo esc_html( get_theme_mod('extreme_lite_mainnavcoloractive','#ec9327')); ?>;}	
	
    </style> 
<?php                                                
}
         
add_action('wp_head','extreme_lite_custom_css');	 

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function extreme_lite_customize_preview_js() {
	wp_enqueue_script( 'extreme_lite_customizer', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '19062019', true );
}
add_action( 'customize_preview_init', 'extreme_lite_customize_preview_js' );